@@ -282,15 +282,7 @@ public class TestNG {
                     cSuite.setParentSuite(s);
                     s.getChildSuites().add(cSuite);
                 }
-            }
-            catch(FileNotFoundException e) {
-                e.printStackTrace(System.out);
-            }
-            catch (ParserConfigurationException e) {
-                e.printStackTrace(System.out);
-            } catch (SAXException e) {
-                e.printStackTrace(System.out);
-            } catch (IOException e) {
+            } catch (ParserConfigurationException | IOException | SAXException e) {
                 e.printStackTrace(System.out);
             }
         }
@@ -319,19 +311,9 @@ public class TestNG {
           }
         }
       }
-      catch(FileNotFoundException e) {
+      catch(SAXException | ParserConfigurationException | IOException e) {
         e.printStackTrace(System.out);
-      }
-      catch(IOException e) {
-        e.printStackTrace(System.out);
-      }
-      catch(ParserConfigurationException e) {
-        e.printStackTrace(System.out);
-      }
-      catch(SAXException e) {
-        e.printStackTrace(System.out);
-      }
-      catch(Exception ex) {
+      } catch(Exception ex) {
         // Probably a Yaml exception, unnest it
         Throwable t = ex;
         while (t.getCause() != null) t = t.getCause();
@@ -375,7 +357,16 @@ public class TestNG {
         JarEntry je = entries.nextElement();
         if (je.getName().equals(m_xmlPathInJar)) {
           Parser parser = getParser(jf.getInputStream(je));
-          m_suites.addAll(parser.parse());
+          Collection<XmlSuite> suites = parser.parse();
+          for (XmlSuite suite : suites) {
+            // If test names were specified, only run these test names
+            if (m_testNames != null) {
+              m_suites.add(extractTestNames(suite, m_testNames));
+            } else {
+              m_suites.add(suite);
+            }
+          }
+
           foundTestngXml = true;
           break;
         }
@@ -400,13 +391,7 @@ public class TestNG {
         m_suites.add(xmlSuite);
       }
     }
-    catch(ParserConfigurationException ex) {
-      ex.printStackTrace();
-    }
-    catch(SAXException ex) {
-      ex.printStackTrace();
-    }
-    catch(IOException ex) {
+    catch(ParserConfigurationException | IOException | SAXException ex) {
       ex.printStackTrace();
     }
   }
@@ -603,7 +588,7 @@ public class TestNG {
       xmlTest.getXmlClasses().add(xmlClasses[i]);
     }
 
-    return new ArrayList<XmlSuite>(suites.values());
+    return new ArrayList<>(suites.values());
   }
 
   public void addMethodSelector(String className, int priority) {
@@ -708,7 +693,7 @@ public class TestNG {
         setAnnotationTransformer((IAnnotationTransformer) listener);
       }
       if (listener instanceof IMethodInterceptor) {
-        setMethodInterceptor((IMethodInterceptor) listener);
+        m_methodInterceptors.add((IMethodInterceptor) listener);
       }
       if (listener instanceof IInvokedMethodListener) {
         addInvokedMethodListener((IInvokedMethodListener) listener);
@@ -774,7 +759,7 @@ public class TestNG {
 
   private Boolean m_skipFailedInvocationCounts = false;
 
-  private IMethodInterceptor m_methodInterceptor = null;
+  private List<IMethodInterceptor> m_methodInterceptors = new ArrayList<IMethodInterceptor>();
 
   /** The list of test names to run from the given suite */
   private List<String> m_testNames;
@@ -940,8 +925,9 @@ public class TestNG {
    * Using reflection to remain Java 5 compliant.
    */
   private void addServiceLoaderListeners() {
-      Iterable<ITestNGListener> loader =
-          ServiceLoader.load(ITestNGListener.class, m_serviceLoaderClassLoader);
+      Iterable<ITestNGListener> loader = m_serviceLoaderClassLoader != null ?
+          ServiceLoader.load(ITestNGListener.class, m_serviceLoaderClassLoader)
+          : ServiceLoader.load(ITestNGListener.class);
       for (ITestNGListener l : loader) {
         Utils.log("[TestNG]", 2, "Adding ServiceLoader listener:" + l);
         addListener(l);
@@ -1128,7 +1114,7 @@ public class TestNG {
         // Multithreaded: generate a dynamic graph that stores the suite hierarchy. This is then
         // used to run related suites in specific order. Parent suites are run only
         // once all the child suites have completed execution
-        DynamicGraph<ISuite> suiteGraph = new DynamicGraph<ISuite>();
+        DynamicGraph<ISuite> suiteGraph = new DynamicGraph<>();
         for (XmlSuite xmlSuite : m_suites) {
           populateSuiteGraph(suiteGraph, suiteRunnerMap, xmlSuite);
         }
@@ -1136,9 +1122,9 @@ public class TestNG {
         IThreadWorkerFactory<ISuite> factory = new SuiteWorkerFactory(suiteRunnerMap,
           0 /* verbose hasn't been set yet */, getDefaultSuiteName());
         GraphThreadPoolExecutor<ISuite> pooledExecutor =
-          new GraphThreadPoolExecutor<ISuite>(suiteGraph, factory, m_suiteThreadPoolSize,
-          m_suiteThreadPoolSize, Integer.MAX_VALUE, TimeUnit.MILLISECONDS,
-          new LinkedBlockingQueue<Runnable>());
+                new GraphThreadPoolExecutor<>(suiteGraph, factory, m_suiteThreadPoolSize,
+                        m_suiteThreadPoolSize, Integer.MAX_VALUE, TimeUnit.MILLISECONDS,
+                        new LinkedBlockingQueue<Runnable>());
 
         Utils.log("TestNG", 2, "Starting executor for all suites");
         // Run all suites in parallel
@@ -1275,7 +1261,7 @@ public class TestNG {
         m_outputDir,
         m_testRunnerFactory,
         m_useDefaultListeners,
-        m_methodInterceptor,
+        m_methodInterceptors,
         m_invokedMethodListeners,
         m_testListeners);
 
@@ -1417,7 +1403,7 @@ public class TestNG {
     }
     if (cla.listener != null) {
       String sep = ";";
-      if (cla.listener.indexOf(",") >= 0) {
+      if (cla.listener.contains(",")) {
         sep = ",";
       }
       String[] strs = Utils.split(cla.listener, sep);
@@ -1856,7 +1842,9 @@ public class TestNG {
     @Override
     public void onTestSkipped(ITestResult result) {
       setHasRunTests();
-      m_mainRunner.setStatus(HAS_SKIPPED);
+      if ((m_mainRunner.getStatus() & HAS_FAILURE) != 0) {
+        m_mainRunner.setStatus(HAS_SKIPPED);
+      }
     }
 
     @Override
@@ -1928,12 +1916,8 @@ public class TestNG {
     m_hookable = h;
   }
 
-  public void setMethodInterceptor(IMethodInterceptor i) {
-	// compare by reference!
-    if (m_methodInterceptor != null && m_methodInterceptor != i) {
-    	LOGGER.warn("MethodInterceptor already set");
-    }
-    m_methodInterceptor = i;
+  public void setMethodInterceptor(IMethodInterceptor methodInterceptor) {
+    m_methodInterceptors.add(methodInterceptor);
   }
 
   public void setDataProviderThreadCount(int count) {
