@@ -1,7 +1,14 @@
 package org.testng.internal;
 
-import static org.testng.internal.invokers.InvokedMethodListenerMethod.AFTER_INVOCATION;
-import static org.testng.internal.invokers.InvokedMethodListenerMethod.BEFORE_INVOCATION;
+import java.lang.annotation.Annotation;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 import org.testng.IClass;
 import org.testng.IConfigurable;
@@ -39,17 +46,8 @@ import org.testng.xml.XmlClass;
 import org.testng.xml.XmlSuite;
 import org.testng.xml.XmlTest;
 
-import java.lang.annotation.Annotation;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.regex.Pattern;
+import static org.testng.internal.invokers.InvokedMethodListenerMethod.AFTER_INVOCATION;
+import static org.testng.internal.invokers.InvokedMethodListenerMethod.BEFORE_INVOCATION;
 
 /**
  * This class is responsible for invoking methods:
@@ -183,11 +181,11 @@ public class Invoker implements IInvoker {
         // Only run the configuration if
         // - the test is enabled and
         // - the Configuration method belongs to the same class or a parent
-        if(MethodHelper.isEnabled(objectClass, m_annotationFinder)) {
-          configurationAnnotation = AnnotationHelper.findConfiguration(m_annotationFinder, method);
+        configurationAnnotation = AnnotationHelper.findConfiguration(m_annotationFinder, method);
+        boolean alwaysRun= isAlwaysRun(configurationAnnotation);
+        if(MethodHelper.isEnabled(objectClass, m_annotationFinder) || alwaysRun) {
 
           if (MethodHelper.isEnabled(configurationAnnotation)) {
-            boolean alwaysRun= isAlwaysRun(configurationAnnotation);
 
             if (!confInvocationPassed(tm, currentTestMethod, testClass, instance) && !alwaysRun) {
               handleConfigurationSkip(tm, testResult, configurationAnnotation, currentTestMethod, instance, suite);
@@ -235,13 +233,7 @@ public class Invoker implements IInvoker {
       }
       catch(InvocationTargetException ex) {
         handleConfigurationFailure(ex, tm, testResult, configurationAnnotation, currentTestMethod, instance, suite);
-      }
-      catch(TestNGException ex) {
-        // Don't wrap TestNGExceptions, it could be a missing parameter on a
-        // @Configuration method
-        handleConfigurationFailure(ex, tm, testResult, configurationAnnotation, currentTestMethod, instance, suite);
-      }
-      catch(Throwable ex) { // covers the non-wrapper exceptions
+      } catch(Throwable ex) { // covers the non-wrapper exceptions
         handleConfigurationFailure(ex, tm, testResult, configurationAnnotation, currentTestMethod, instance, suite);
       }
     } // for methods
@@ -273,7 +265,11 @@ public class Invoker implements IInvoker {
     if ((configurationAnnotation.getAfterSuite()
         || configurationAnnotation.getAfterTest()
         || configurationAnnotation.getAfterTestClass()
-        || configurationAnnotation.getAfterTestMethod())
+        || configurationAnnotation.getAfterTestMethod()
+        || configurationAnnotation.getBeforeTestMethod()
+        || configurationAnnotation.getBeforeTestClass()
+        || configurationAnnotation.getBeforeTest()
+        || configurationAnnotation.getBeforeSuite())
         && configurationAnnotation.getAlwaysRun())
     {
         alwaysRun= true;
@@ -398,7 +394,7 @@ public class Invoker implements IInvoker {
    */
   private boolean classConfigurationFailed(Class<?> cls) {
     for (Class<?> c : m_classInvocationResults.keySet()) {
-      if (c == cls || cls.isAssignableFrom(c)) {
+      if (c == cls || c.isAssignableFrom(cls)) {
         return true;
       }
     }
@@ -413,10 +409,7 @@ public class Invoker implements IInvoker {
       IClass testClass, Object instance) {
     boolean result= true;
 
-    // If continuing on config failure, check invocation results for the class
-    // under test, otherwise use the method's declaring class
-    Class<?> cls = m_continueOnFailedConfiguration ?
-            testClass.getRealClass() : method.getMethod().getDeclaringClass();
+    Class<?> cls = testClass.getRealClass();
 
     if(m_suiteState.isFailed()) {
       result= false;
@@ -526,19 +519,10 @@ public class Invoker implements IInvoker {
           }
         }
       }
-      catch (InvocationTargetException ex) {
+      catch (InvocationTargetException | IllegalAccessException ex) {
        throwConfigurationFailure(testResult, ex);
        throw ex;
-      }
-      catch (IllegalAccessException ex) {
-        throwConfigurationFailure(testResult, ex);
-        throw ex;
-      }
-      catch (NoSuchMethodException ex) {
-        throwConfigurationFailure(testResult, ex);
-        throw new TestNGException(ex);
-      }
-      catch (Throwable ex) {
+      } catch (Throwable ex) {
         throwConfigurationFailure(testResult, ex);
         throw new TestNGException(ex);
       }
@@ -639,34 +623,26 @@ public class Invoker implements IInvoker {
       if(confInvocationPassed(tm, tm, testClass, instance)) {
         log(3, "Invoking " + tm.getRealClass().getName() + "." + tm.getMethodName());
 
-        // If no timeOut, just invoke the method
-        if (MethodHelper.calculateTimeOut(tm) <= 0) {
-          Reporter.setCurrentTestResult(testResult);
-          //
-          // If this method is a IHookable, invoke its run() method
-          //
-          IHookable hookableInstance =
-              IHookable.class.isAssignableFrom(tm.getRealClass()) ?
+        Reporter.setCurrentTestResult(testResult);
+
+        // If this method is a IHookable, invoke its run() method
+        IHookable hookableInstance =
+            IHookable.class.isAssignableFrom(tm.getRealClass()) ?
             (IHookable) instance : m_configuration.getHookable();
+
+        if (MethodHelper.calculateTimeOut(tm) <= 0) {
           if (hookableInstance != null) {
             MethodInvocationHelper.invokeHookable(instance,
                 parameterValues, hookableInstance, thisMethod, testResult);
-          }
-          //
-          // Not a IHookable, invoke directly
-          //
-          else {
+          } else {
+            // Not a IHookable, invoke directly
             MethodInvocationHelper.invokeMethod(thisMethod, instance,
                 parameterValues);
           }
           testResult.setStatus(ITestResult.SUCCESS);
-        }
-        else {
-          //
+        } else {
           // Method with a timeout
-          //
-          Reporter.setCurrentTestResult(testResult);
-          MethodInvocationHelper.invokeWithTimeout(tm, instance, parameterValues, testResult);
+          MethodInvocationHelper.invokeWithTimeout(tm, instance, parameterValues, testResult, hookableInstance);
         }
       }
       else {
@@ -696,7 +672,7 @@ public class Invoker implements IInvoker {
       testResult.setEndMillis(System.currentTimeMillis());
 
       ExpectedExceptionsHolder expectedExceptionClasses
-          = MethodHelper.findExpectedExceptions(m_annotationFinder, tm.getMethod());
+          = new ExpectedExceptionsHolder(m_annotationFinder, tm, new RegexpExpectedExceptionsHolder(m_annotationFinder, tm));
       List<ITestResult> results = Lists.<ITestResult>newArrayList(testResult);
       handleInvocationResults(tm, results, expectedExceptionClasses, false,
           false /* collect results */, failureContext);
@@ -813,7 +789,7 @@ public class Invoker implements IInvoker {
   }
 
   /**
-   * {@link #invokeTestMethods()} eventually converge here to invoke a single @Test method.
+   * invokeTestMethods() eventually converge here to invoke a single @Test method.
    * <p/>
    * This method is responsible for actually invoking the method. It decides if the invocation
    * must be done:
@@ -843,7 +819,8 @@ public class Invoker implements IInvoker {
     tm.setId(ThreadUtil.currentThreadInfo());
 
     ITestResult result = invokeMethod(instance, tm, parameterValues, parametersIndex, suite, params,
-        testClass, beforeMethods, afterMethods, groupMethods, failureContext);
+                                      testClass, beforeMethods, afterMethods, groupMethods,
+                                      failureContext);
 
     return result;
   }
@@ -1083,7 +1060,8 @@ public class Invoker implements IInvoker {
     int invocationCount = onlyOne ? 1 : testMethod.getInvocationCount();
 
     ExpectedExceptionsHolder expectedExceptionHolder =
-        MethodHelper.findExpectedExceptions(m_annotationFinder, testMethod.getMethod());
+        new ExpectedExceptionsHolder(m_annotationFinder, testMethod,
+                                     new RegexpExpectedExceptionsHolder(m_annotationFinder, testMethod));
     final ITestClass testClass= testMethod.getTestClass();
     final List<ITestResult> result = Lists.newArrayList();
     final FailureContext failure = new FailureContext();
@@ -1136,7 +1114,7 @@ public class Invoker implements IInvoker {
               parametersIndex++;
             }
             PoolService<List<ITestResult>> ps =
-                new PoolService<List<ITestResult>>(suite.getDataProviderThreadCount());
+                    new PoolService<>(suite.getDataProviderThreadCount());
             List<List<ITestResult>> r = ps.submitTasksAndWait(workers);
             for (List<ITestResult> l2 : r) {
               result.addAll(l2);
@@ -1239,7 +1217,6 @@ public class Invoker implements IInvoker {
    * @param method method to be invoked
    * @param context test context
    * @param testResult test result
-   * @return
    */
   private Object[] injectParameters(Object[] parameterValues, Method method,
       ITestContext context, ITestResult testResult)
@@ -1353,7 +1330,8 @@ public class Invoker implements IInvoker {
           testContext));
     }
 
-    return runWorkers(testMethod, workers, testMethod.getThreadPoolSize(), groupMethods, suite, parameters);
+    return runWorkers(testMethod, workers, testMethod.getThreadPoolSize(), groupMethods, suite,
+                      parameters);
   }
 
   static class FailureContext {
@@ -1361,13 +1339,6 @@ public class Invoker implements IInvoker {
     List<Object> instances = Lists.newArrayList();
   }
 
-  /**
-   * @param testMethod
-   * @param result
-   * @param expectedExceptionsHolder
-   * @param failure
-   * @return
-   */
   void handleInvocationResults(ITestNGMethod testMethod,
                                List<ITestResult> result,
                                ExpectedExceptionsHolder expectedExceptionsHolder,
@@ -1389,27 +1360,18 @@ public class Invoker implements IInvoker {
       // Exception thrown?
       if (ite != null) {
 
+        if (isSkipExceptionAndSkip(ite)){
+          status = ITestResult.SKIP;
+        }
         //  Invocation caused an exception, see if the method was annotated with @ExpectedException
-        if (isExpectedException(ite, expectedExceptionsHolder)) {
-          if (messageRegExpMatches(expectedExceptionsHolder.messageRegExp, ite)) {
+        else if (expectedExceptionsHolder != null) {
+          if (expectedExceptionsHolder.isExpectedException(ite)) {
             testResult.setStatus(ITestResult.SUCCESS);
-            status= ITestResult.SUCCESS;
-          }
-          else {
-            testResult.setThrowable(
-                new TestException("The exception was thrown with the wrong message:" +
-                    " expected \"" + expectedExceptionsHolder.messageRegExp + "\"" +
-                    " but got \"" + ite.getMessage() + "\"", ite));
+            status = ITestResult.SUCCESS;
+          } else {
+            testResult.setThrowable(expectedExceptionsHolder.wrongException(ite));
             status= ITestResult.FAILURE;
           }
-        } else if (isSkipExceptionAndSkip(ite)){
-          status = ITestResult.SKIP;
-        } else if (expectedExceptionsHolder != null) {
-          testResult.setThrowable(
-              new TestException("Expected exception of " +
-                  getExpectedExceptionsPluralize(expectedExceptionsHolder)
-                  + " but got " + ite, ite));
-          status= ITestResult.FAILURE;
         } else {
           handleException(ite, testMethod, testResult, failure.count++);
           handled = true;
@@ -1419,28 +1381,24 @@ public class Invoker implements IInvoker {
 
       // No exception thrown, make sure we weren't expecting one
       else if(status != ITestResult.SKIP && expectedExceptionsHolder != null) {
-        Class<?>[] classes = expectedExceptionsHolder.expectedClasses;
-        if (classes != null && classes.length > 0) {
-          testResult.setThrowable(
-              new TestException("Method " + testMethod + " should have thrown an exception of "
-                  + getExpectedExceptionsPluralize(expectedExceptionsHolder)));
+        TestException exception = expectedExceptionsHolder.noException(testMethod);
+        if (exception != null) {
+          testResult.setThrowable(exception);
           status= ITestResult.FAILURE;
         }
       }
 
-      testResult.setStatus(status);
+      IRetryAnalyzer retryAnalyzer = testMethod.getRetryAnalyzer();
+      boolean willRetry = retryAnalyzer != null && status == ITestResult.FAILURE && failure.instances != null && retryAnalyzer.retry(testResult);
 
-      if (status == ITestResult.FAILURE && !handled) {
-        handleException(ite, testMethod, testResult, failure.count++);
-        status = testResult.getStatus();
-      }
-
-      if (status == ITestResult.FAILURE) {
-        IRetryAnalyzer retryAnalyzer = testMethod.getRetryAnalyzer();
-
-        if (retryAnalyzer != null &&  failure.instances != null && retryAnalyzer.retry(testResult)) {
-          resultsToRetry.add(testResult);
-          failure.instances.add(testResult.getInstance());
+      if (willRetry) {
+        resultsToRetry.add(testResult);
+        failure.instances.add(testResult.getInstance());
+        testResult.setStatus(ITestResult.SKIP);
+      } else {
+        testResult.setStatus(status);
+        if (status == ITestResult.FAILURE && !handled) {
+          handleException(ite, testMethod, testResult, failure.count++);
         }
       }
       if (collectResults) {
@@ -1455,36 +1413,10 @@ public class Invoker implements IInvoker {
     removeResultsToRetryFromResult(resultsToRetry, result, failure);
   }
 
-  private String getExpectedExceptionsPluralize(final ExpectedExceptionsHolder holder) {
-    StringBuilder sb = new StringBuilder();
-    if (holder.expectedClasses.length > 1) {
-      sb.append("any of types ");
-      sb.append(Arrays.toString(holder.expectedClasses));
-    } else {
-      sb.append("type ");
-      sb.append(holder.expectedClasses[0]);
-    }
-    return sb.toString();
-  }
-
   private boolean isSkipExceptionAndSkip(Throwable ite) {
     return SkipException.class.isAssignableFrom(ite.getClass()) && ((SkipException) ite).isSkip();
   }
 
-  /**
-   *   message / regEx  .*      other
-   *   null             true    false
-   *   non-null         true    match
-   */
-  private boolean messageRegExpMatches(String messageRegExp, Throwable ite) {
-    if (".*".equals(messageRegExp)) {
-      return true;
-    } else {
-      final String message = ite.getMessage();
-      return message != null && Pattern.compile(messageRegExp, Pattern.DOTALL).matcher(ite.getMessage()).matches();
-    }
-  }
-
   private void removeResultsToRetryFromResult(List<ITestResult> resultsToRetry,
                                               List<ITestResult> result, FailureContext failure) {
     if (resultsToRetry != null) {
@@ -1676,36 +1608,6 @@ public class Invoker implements IInvoker {
 
   }
 
-  /**
-   * @param ite The exception that was just thrown
-   * @param exceptionHolder Expected exceptions holder for this
-   * test method
-   * @return true if the exception that was just thrown is part of the
-   * expected exceptions
-   */
-  private boolean isExpectedException(Throwable ite, ExpectedExceptionsHolder exceptionHolder) {
-    if (exceptionHolder == null || exceptionHolder.expectedClasses == null) {
-      return false;
-    }
-
-    // TestException is the wrapper exception that TestNG will be throwing when an exception was
-    // expected but not thrown
-    if (ite.getClass() == TestException.class) {
-      return false;
-    }
-
-    Class<?>[] exceptions = exceptionHolder.expectedClasses;
-    Class<?> realExceptionClass= ite.getClass();
-
-    for (Class<?> exception : exceptions) {
-      if (exception.isAssignableFrom(realExceptionClass)) {
-        return true;
-      }
-    }
-
-    return false;
-  }
-
   static interface Predicate<K, T> {
     boolean isTrue(K k, T v);
   }
