@@ -3,8 +3,8 @@ package org.testng.internal.annotations;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
-import java.util.Collections;
 import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.testng.IAnnotationTransformer;
 import org.testng.IAnnotationTransformer2;
@@ -37,7 +37,6 @@ import org.testng.annotations.Optional;
 import org.testng.annotations.Parameters;
 import org.testng.annotations.Test;
 import org.testng.annotations.TestInstance;
-import org.testng.collections.Maps;
 import org.testng.internal.collections.Pair;
 
 /**
@@ -49,8 +48,9 @@ import org.testng.internal.collections.Pair;
 public class JDK15AnnotationFinder implements IAnnotationFinder {
   private JDK15TagFactory m_tagFactory = new JDK15TagFactory();
   private Map<Class<? extends IAnnotation>, Class<? extends Annotation>> m_annotationMap =
-      Collections.synchronizedMap(Maps.<Class<? extends IAnnotation>,
-          Class<? extends Annotation>>newHashMap());
+      new ConcurrentHashMap<>();
+  private Map<Pair<Annotation, ?>, IAnnotation> m_annotations = new ConcurrentHashMap<>();
+
   private IAnnotationTransformer m_transformer = null;
 
   @SuppressWarnings({"deprecation"})
@@ -105,7 +105,7 @@ public class JDK15AnnotationFinder implements IAnnotationFinder {
           + annotationClass + "' not found.");
     }
     Annotation annotation = m.getAnnotation(a);
-    return findAnnotation(annotation, annotationClass, m.getDeclaringClass(), null, m,
+    return findAnnotation(m.getDeclaringClass(), annotation, annotationClass, null, null, m,
         new Pair<>(annotation, m));
   }
 
@@ -127,7 +127,7 @@ public class JDK15AnnotationFinder implements IAnnotationFinder {
     if (annotation == null) {
       annotation = testClass.getAnnotation(a);
     }
-    return findAnnotation(annotation, annotationClass, testClass, null, m,
+    return findAnnotation(testClass, annotation, annotationClass, null, null, m,
         new Pair<>(annotation, m));
   }
 
@@ -175,7 +175,7 @@ public class JDK15AnnotationFinder implements IAnnotationFinder {
           + annotationClass + "' not found.");
     }
     Annotation annotation = findAnnotationInSuperClasses(cls, a);
-    return findAnnotation(annotation, annotationClass, cls, null, null,
+    return findAnnotation(cls, annotation, annotationClass, cls, null, null,
         new Pair<>(annotation, annotationClass));
   }
 
@@ -187,18 +187,20 @@ public class JDK15AnnotationFinder implements IAnnotationFinder {
           + annotationClass + "' not found.");
     }
     Annotation annotation = cons.getAnnotation(a);
-    return findAnnotation(annotation, annotationClass, cons.getDeclaringClass(), cons, null,
+    return findAnnotation(cons.getDeclaringClass(), annotation, annotationClass, null, cons, null,
         new Pair<>(annotation, cons));
   }
 
-  private Map<Pair<Annotation, ?>, IAnnotation> m_annotations = Maps.newHashMap();
-
-  private <A extends IAnnotation> A findAnnotation(Annotation a,
+  private <A extends IAnnotation> A findAnnotation(Class cls, Annotation a,
       Class<A> annotationClass, Class<?> testClass,
       Constructor<?> testConstructor, Method testMethod, Pair<Annotation, ?> p) {
+    if (a == null) {
+      return null;
+    }
+
     IAnnotation result = m_annotations.get(p);
     if (result == null) {
-      result = m_tagFactory.createTag(testClass, a, annotationClass, m_transformer);
+      result = m_tagFactory.createTag(cls, a, annotationClass, m_transformer);
       m_annotations.put(p, result);
       transform(result, testClass, testConstructor, testMethod);
     }
