@@ -32,7 +32,7 @@ public class MethodInstanceTest {
 
     // Build a list of entries imposing the same behavior as the live suite, reduced to the
     // minimum to create the same condition.
-    List<MethodInstance> methods = new ArrayList<MethodInstance>();
+    List<MethodInstance> methods = new ArrayList<>();
     methods.add(buildMethodInstance("unittests", "StateTest", 1, "aCategorization"));
     methods.add(buildMethodInstance("unittests", "StateTest", 1, "bCategorization"));
     methods.add(buildMethodInstance("unittests", "StateTest", 1, "cCategorization"));
@@ -466,6 +466,10 @@ public class MethodInstanceTest {
       return null;
     }
 
+    @Override
+    public void setDescription(String description) {
+    }
+
     @Override
     public void incrementCurrentInvocationCount() {
     }
